==> django-froala-editor-0.8.0.tar.gz: django-froala-editor-0.8.0/froala_editor/static/froala_editor/js/langs/fa.js <==
/**
 * Persian
 */

$.Editable.LANGS['fa'] = {
  translation: {
    "Bold": "\u062f\u0631\u0634\u062a",
    "Italic": "\u062e\u0637 \u06a9\u062c",
    "Underline": "\u062e\u0637 \u0632\u06cc\u0631",
    "Strikethrough": "\u062e\u0637 \u062e\u0648\u0631\u062f\u0647",
    "Font Size": "\u0627\u0646\u062f\u0627\u0632\u0647 \u0641\u0648\u0646\u062a",
    "Color": "\u0631\u0646\u06af",
    "Background Color": "\u0631\u0646\u06af \u0632\u0645\u06cc\u0646\u0647 \u0645\u062a\u0646",
    "Text Color": "\u0631\u0646\u06af \u0645\u062a\u0646",
    "Format Block": "\u0642\u0627\u0644\u0628",
    "Normal": "\u0637\u0628\u06cc\u0639\u06cc - Normal",
    "Paragraph": "\u067e\u0627\u0631\u0627\u06af\u0631\u0627\u0641 - Paragraph",
    "Code": "\u062f\u0633\u062a\u0648\u0631\u0627\u0644\u0639\u0645\u0644\u0647\u0627 - Code",
    "Quote": "\u0646\u0642\u0644 \u0628\u06cc\u0627\u0646 \u06a9\u0631\u062f\u0646 - Quote",
    "Heading 1": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 1",
    "Heading 2": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 2",
    "Heading 3": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 3",
    "Heading 4": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 4",
    "Heading 5": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 5",
    "Heading 6": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 6",
    "Alignment": "\u0631\u062f\u06cc\u0641 \u0628\u0646\u062f\u06cc \u0646\u0648\u0634\u062a\u0647",
    "Align Left": "\u0686\u067e \u0686\u06cc\u0646",
    "Align Center": "\u0648\u0633\u0637 \u0686\u06cc\u0646",
    "Align Right": "\u0631\u0627\u0633\u062a \u0686\u06cc\u0646",
    "Justify": "\u0645\u0633\u0627\u0648\u06cc \u0627\u0632 \u0637\u0631\u0641\u06cc\u0646",
    "Numbered List": "\u0644\u06cc\u0633\u062a \u0634\u0645\u0627\u0631\u0647 \u0627\u06cc",
    "Bulleted List": "\u0644\u06cc\u0633\u062a \u062f\u0627\u06cc\u0631\u0647 \u0627\u06cc",
    "Indent Less": "\u06a9\u0627\u0647\u0634 \u062a\u0648 \u0631\u0641\u062a\u06af\u06cc",
    "Indent More": "\u0627\u0641\u0632\u0627\u06cc\u0634 \u062a\u0648 \u0631\u0641\u062a\u06af\u06cc",
    "Select All": "\u0627\u0646\u062a\u062e\u0627\u0628 \u0647\u0645\u0647",
    "Insert Link": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u0644\u06cc\u0646\u06a9",
    "Insert Image": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u062a\u0635\u0648\u06cc\u0631",
    "Insert Video": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u0641\u0627\u06cc\u0644 \u062a\u0635\u0648\u06cc\u0631\u06cc",
    "Undo": "\u0628\u0627\u0637\u0644 \u06a9\u0631\u062f\u0646",
    "Redo": "\u0627\u0646\u062c\u0627\u0645 \u062f\u0648\u0628\u0627\u0631\u0647",
    "Show HTML": "HTML \u0646\u0645\u0627\u06cc\u0634",
    "Float Left": "\u0686\u067e",
    "Float None": "\u0647\u06cc\u0686 \u06a9\u062f\u0627\u0645",
    "Float Right": "\u0631\u0627\u0633\u062a",
    "Replace Image": "\u0628\u0647 \u062c\u0627\u06cc \u062a\u0635\u0648\u06cc\u0631",
    "Remove Image": "\u062d\u0630\u0641 \u062a\u0635\u0648\u06cc\u0631",
    "Title": "\u0639\u0646\u0648\u0627\u0646",
    "Insert image": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u062a\u0635\u0648\u06cc\u0631",
    "Drop image": "\u0642\u0637\u0631\u0647 \u062a\u0635\u0648\u06cc\u0631",
    "or click": "\u06cc\u0627 \u06a9\u0644\u06cc\u06a9 \u06a9\u0646\u06cc\u062f",
    "Enter URL": "\u0631\u0627 \u0648\u0627\u0631\u062f \u06a9\u0646\u06cc\u062f URL",
    "Please wait!": "!\u0644\u0637\u0641\u0627 \u0635\u0628\u0631 \u06a9\u0646\u06cc\u062f",
    "Are you sure? Image will be deleted.": ".\u0622\u06cc\u0627 \u0645\u0637\u0645\u0626\u0646 \u0647\u0633\u062a\u06cc\u062f\u061f \u062a\u0635\u0648\u06cc\u0631 \u062d\u0630\u0641 \u062e\u0648\u0627\u0647\u062f \u0634\u062f",
    "UNLINK": "\u062d\u0630\u0641 \u0644\u06cc\u0646\u06a9",
    "Open in new tab": "\u0628\u0627\u0632 \u06a9\u0631\u062f\u0646 \u062f\u0631 \u0628\u0631\u06af\u0647 \u062c\u062f\u06cc\u062f",
    "Type something": "\u0686\u06cc\u0632\u06cc \u0628\u0646\u0648\u06cc\u0633\u06cc\u062f",
    "Cancel": "\u0644\u063a\u0648",
    "OK": "\u0628\u0627\u0634\u0647",
    "Manage images": "\u0645\u062f\u06cc\u0631\u06cc\u062a \u062a\u0635\u0627\u0648\u06cc\u0631",
    "Delete": "\u062d\u0630\u0641 \u06a9\u0631\u062f\u0646",
    "Font Family": "\u0641\u0648\u0646\u062a",
    "Insert Horizontal Line": "\u0642\u0631\u0627\u0631 \u062f\u0627\u062f\u0646 \u0627\u0641\u0642\u06cc \u062e\u0637"
  },
  direction : "rtl"
};

==> django-froala-editor-0.8.3.tar.gz: django-froala-editor-0.8.3/froala_editor/static/froala_editor/js/langs/fa.js <==
/*!
 * froala_editor v1.1.6 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Persian
 */

$.Editable.LANGS['fa'] = {
  translation: {
    "Bold": "\u062f\u0631\u0634\u062a",
    "Italic": "\u062e\u0637 \u06a9\u062c",
    "Underline": "\u062e\u0637 \u0632\u06cc\u0631",
    "Strikethrough": "\u062e\u0637 \u062e\u0648\u0631\u062f\u0647",
    "Font Size": "\u0627\u0646\u062f\u0627\u0632\u0647 \u0641\u0648\u0646\u062a",
    "Color": "\u0631\u0646\u06af",
    "Background Color": "\u0631\u0646\u06af \u0632\u0645\u06cc\u0646\u0647 \u0645\u062a\u0646",
    "Text Color": "\u0631\u0646\u06af \u0645\u062a\u0646",
    "Format Block": "\u0642\u0627\u0644\u0628",
    "Normal": "\u0637\u0628\u06cc\u0639\u06cc - Normal",
    "Paragraph": "\u067e\u0627\u0631\u0627\u06af\u0631\u0627\u0641 - Paragraph",
    "Code": "\u062f\u0633\u062a\u0648\u0631\u0627\u0644\u0639\u0645\u0644\u0647\u0627 - Code",
    "Quote": "\u0646\u0642\u0644 \u0628\u06cc\u0627\u0646 \u06a9\u0631\u062f\u0646 - Quote",
    "Heading 1": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 1",
    "Heading 2": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 2",
    "Heading 3": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 3",
    "Heading 4": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 4",
    "Heading 5": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 5",
    "Heading 6": "\u0633\u0631\u200c\u0635\u0641\u062d\u0647 6",
    "Alignment": "\u0631\u062f\u06cc\u0641 \u0628\u0646\u062f\u06cc \u0646\u0648\u0634\u062a\u0647",
    "Align Left": "\u0686\u067e \u0686\u06cc\u0646",
    "Align Center": "\u0648\u0633\u0637 \u0686\u06cc\u0646",
    "Align Right": "\u0631\u0627\u0633\u062a \u0686\u06cc\u0646",
    "Justify": "\u0645\u0633\u0627\u0648\u06cc \u0627\u0632 \u0637\u0631\u0641\u06cc\u0646",
    "Numbered List": "\u0644\u06cc\u0633\u062a \u0634\u0645\u0627\u0631\u0647 \u0627\u06cc",
    "Bulleted List": "\u0644\u06cc\u0633\u062a \u062f\u0627\u06cc\u0631\u0647 \u0627\u06cc",
    "Indent Less": "\u06a9\u0627\u0647\u0634 \u062a\u0648 \u0631\u0641\u062a\u06af\u06cc",
    "Indent More": "\u0627\u0641\u0632\u0627\u06cc\u0634 \u062a\u0648 \u0631\u0641\u062a\u06af\u06cc",
    "Select All": "\u0627\u0646\u062a\u062e\u0627\u0628 \u0647\u0645\u0647",
    "Insert Link": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u0644\u06cc\u0646\u06a9",
    "Insert Image": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u062a\u0635\u0648\u06cc\u0631",
    "Insert Video": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u0641\u0627\u06cc\u0644 \u062a\u0635\u0648\u06cc\u0631\u06cc",
    "Undo": "\u0628\u0627\u0637\u0644 \u06a9\u0631\u062f\u0646",
    "Redo": "\u0627\u0646\u062c\u0627\u0645 \u062f\u0648\u0628\u0627\u0631\u0647",
    "Show HTML": "HTML \u0646\u0645\u0627\u06cc\u0634",
    "Float Left": "\u0686\u067e",
    "Float None": "\u0647\u06cc\u0686 \u06a9\u062f\u0627\u0645",
    "Float Right": "\u0631\u0627\u0633\u062a",
    "Replace Image": "\u0628\u0647 \u062c\u0627\u06cc \u062a\u0635\u0648\u06cc\u0631",
    "Remove Image": "\u062d\u0630\u0641 \u062a\u0635\u0648\u06cc\u0631",
    "Title": "\u0639\u0646\u0648\u0627\u0646",
    "Insert image": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u062a\u0635\u0648\u06cc\u0631",
    "Drop image": "\u0642\u0637\u0631\u0647 \u062a\u0635\u0648\u06cc\u0631",
    "or click": "\u06cc\u0627 \u06a9\u0644\u06cc\u06a9 \u06a9\u0646\u06cc\u062f",
    "Enter URL": "\u0631\u0627 \u0648\u0627\u0631\u062f \u06a9\u0646\u06cc\u062f URL",
    "Please wait!": "!\u0644\u0637\u0641\u0627 \u0635\u0628\u0631 \u06a9\u0646\u06cc\u062f",
    "Are you sure? Image will be deleted.": ".\u0622\u06cc\u0627 \u0645\u0637\u0645\u0626\u0646 \u0647\u0633\u062a\u06cc\u062f\u061f \u062a\u0635\u0648\u06cc\u0631 \u062d\u0630\u0641 \u062e\u0648\u0627\u0647\u062f \u0634\u062f",
    "UNLINK": "\u062d\u0630\u0641 \u0644\u06cc\u0646\u06a9",
    "Open in new tab": "\u0628\u0627\u0632 \u06a9\u0631\u062f\u0646 \u062f\u0631 \u0628\u0631\u06af\u0647 \u062c\u062f\u06cc\u062f",
    "Type something": "\u0686\u06cc\u0632\u06cc \u0628\u0646\u0648\u06cc\u0633\u06cc\u062f",
    "Cancel": "\u0644\u063a\u0648",
    "OK": "\u0628\u0627\u0634\u0647",
    "Manage images": "\u0645\u062f\u06cc\u0631\u06cc\u062a \u062a\u0635\u0627\u0648\u06cc\u0631",
    "Delete": "\u062d\u0630\u0641 \u06a9\u0631\u062f\u0646",
    "Font Family": "\u0641\u0648\u0646\u062a",
    "Insert Horizontal Line": "\u0642\u0631\u0627\u0631 \u062f\u0627\u062f\u0646 \u0627\u0641\u0642\u06cc \u062e\u0637",
    "Table": "\u062c\u062f\u0648\u0644",
    "Insert table": "\u0627\u0636\u0627\u0641\u0647 \u06a9\u0631\u062f\u0646 \u062c\u062f\u0648\u0644",
    "Cell": "\u0633\u0644\u0648\u0644",
    "Row": "\u0633\u0637\u0631",
    "Column": "\u0633\u062a\u0648\u0646",
    "Delete table": "\u062d\u0630\u0641 \u062c\u062f\u0648\u0644",
    "Insert cell before": "\u0627\u0636\u0627\u0641\u0647 \u0633\u0644\u0648\u0644 \u0642\u0628\u0644",
    "Insert cell after": "\u0627\u0636\u0627\u0641\u0647 \u0633\u0644\u0648\u0644 \u0628\u0639\u062f",
    "Delete cell": "\u062d\u0630\u0641 \u0633\u0644\u0648\u0644",
    "Merge cells": "\u0627\u062f\u063a\u0627\u0645 \u0633\u0644\u0648\u0644\u200c\u0647\u0627",
    "Horizontal split": "\u062a\u0642\u0633\u06cc\u0645 \u0627\u0641\u0642\u06cc",
    "Vertical split": "\u062a\u0642\u0633\u06cc\u0645 \u0639\u0645\u0648\u062f\u06cc",
    "Insert row above": "\u062f\u0631\u062c \u0631\u062f\u06cc\u0641 \u062f\u0631 \u0628\u0627\u0644\u0627",
    "Insert row below": "\u0633\u0637\u0631 \u0632\u06cc\u0631 \u0631\u0627 \u0648\u0627\u0631\u062f \u06a9\u0646\u06cc\u062f",
    "Delete row": "\u062d\u0630\u0641 \u0633\u0637\u0631",
    "Insert column before": "\u062f\u0631\u062c \u0633\u062a\u0648\u0646 \u0642\u0628\u0644",
    "Insert column after": "\u062f\u0631\u062c \u0633\u062a\u0648\u0646 \u0628\u0639\u062f",
    "Delete column": "\u062d\u0630\u0641 \u0633\u062a\u0648\u0646"
  },
  direction : "rtl"
};
